@@ -110,7 +110,7 @@ has 'raiseHandOnEnter' => (is => 'rw', isa => 'Bool',
     );
 
 has 'recordingModeType' => (is => 'rw', isa => 'Int',
-			    documentation => '0, 1, 2',
+			    documentation => 'Recording mode type: 1:manual, 2:automatic, 3:disabled',
     );
 
 has 'reserveSeats' => (is => 'rw', isa => 'Int',
@@ -136,20 +136,22 @@ has 'versionId' => (is => 'rw', isa => 'Int',
 
 =head2 attendance
 
-    my $today = DateTime->yesterday->subtract(days => 1);
+    my $yesterday = DateTime->today->subtract(days => 1);
 
     my $attendance = $session->attendance( $yesterday->epoch.'000' );
 
-Reports on session attendance for a given day. It returns a reference to an array of Elive::StandardV2::SessionAttendance objects.
+Reports on session attendance for a given day. It returns a reference to an array of L<Elive::StandardV2::SessionAttendance> objects.
 
 =cut
 
 sub attendance {
     my ($self, $start_time, %opt) = @_;
 
-    return Elive::StandardV2::SessionAttendance->list(filter => {
-	sessionId => $self->sessionId,
-	startTime => $start_time,},
+    return Elive::StandardV2::SessionAttendance->list(
+	filter=> {
+	    sessionId => $self->sessionId,
+	    startTime => $start_time,
+	},
 	connection => $self->connection,
 	%opt,
 	);
@@ -163,8 +165,8 @@ sub attendance {
         chairPIN   => '6342',
      });
 
-Returns an Elive::StandardV2::Telephony object for the given session. This can then
-be used to get or set the sessions's telephony characterisitics.
+Returns an L<Elive::StandardV2::Telephony> object for the given session. This
+can then be used to get or set the sessions's telephony characterisitics.
 
 =cut
 
@@ -180,7 +182,9 @@ sub telephony {
 
 =head2 set_presentation
 
-Sets the list of presentation ids for a given session
+    $session->set_presentation([$presentation_1, $presentation_2]);
+
+Associates Presentations with Sessions.
 
 =cut
 
@@ -213,6 +217,43 @@ sub set_presentation {
     return $success;
 }
 			      
+=head2 set_multimedia
+
+    $session->set_multimedia([$multimedia_1, $multimedia_2]);
+
+Associates Multimedias with Sessions.
+
+=cut
+
+sub set_multimedia {
+    my ($class, $multimedia_ids, %opt) = @_;
+
+    my $session_id = delete $opt{sessionId};
+    $session_id ||= $class->sessionId
+	if Scalar::Util::blessed($class);
+
+    croak 'usage: $'.(ref($class)||$class).'->set_multimedia(\@multimedia_ids)'
+	unless Scalar::Util::reftype( $multimedia_ids ) eq 'ARRAY';
+
+    my $connection = $opt{connection} || $class->connection
+	or croak "Not connected";
+
+    my $som = $connection->call(
+	'setSessionMultimedia',
+	sessionId => Elive::Util::_freeze($session_id, 'Int'),
+	multimediaIds => Elive::Util::_freeze($multimedia_ids, 'Elive::StandardV2::List'),
+	);
+
+    my $results = $class->_get_results(
+	$som,
+	$connection,
+	);
+
+    my $success = @$results && $results->[0];
+
+    return $success;
+}
+			      
 =head2 session_url
 
     my $session_url = $session->session_url(user_id => 'bob');
